==> imp-doc-2.1.1.tar.gz: html/namespaceIMP_1_1saxs.js <==
var namespaceIMP_1_1saxs =
[
    [ "ChiFreeScore", "classIMP_1_1saxs_1_1ChiFreeScore.html", "classIMP_1_1saxs_1_1ChiFreeScore" ],
    [ "ChiScore", "classIMP_1_1saxs_1_1ChiScore.html", "classIMP_1_1saxs_1_1ChiScore" ],
    [ "ChiScoreLog", "classIMP_1_1saxs_1_1ChiScoreLog.html", "classIMP_1_1saxs_1_1ChiScoreLog" ],
    [ "DeltaDistributionFunction", "classIMP_1_1saxs_1_1DeltaDistributionFunction.html", "classIMP_1_1saxs_1_1DeltaDistributionFunction" ],
    [ "DerivativeCalculator", "classIMP_1_1saxs_1_1DerivativeCalculator.html", "classIMP_1_1saxs_1_1DerivativeCalculator" ],
    [ "Distribution", "classIMP_1_1saxs_1_1Distribution.html", "classIMP_1_1saxs_1_1Distribution" ],
    [ "FormFactorTable", "classIMP_1_1saxs_1_1FormFactorTable.html", "classIMP_1_1saxs_1_1FormFactorTable" ],
    [ "Profile", "classIMP_1_1saxs_1_1Profile.html", "classIMP_1_1saxs_1_1Profile" ],
    [ "ProfileFitter", "classIMP_1_1saxs_1_1ProfileFitter.html", "classIMP_1_1saxs_1_1ProfileFitter" ],
    [ "RadialDistributionFunction", "classIMP_1_1saxs_1_1RadialDistributionFunction.html", "classIMP_1_1saxs_1_1RadialDistributionFunction" ],
    [ "RadiusOfGyrationRestraint", "classIMP_1_1saxs_1_1RadiusOfGyrationRestraint.html", "classIMP_1_1saxs_1_1RadiusOfGyrationRestraint" ],
    [ "Restraint", "classIMP_1_1saxs_1_1Restraint.html", "classIMP_1_1saxs_1_1Restraint" ],
    [ "SolventAccessibleSurface", "classIMP_1_1saxs_1_1SolventAccessibleSurface.html", "classIMP_1_1saxs_1_1SolventAccessibleSurface" ],
    [ "WeightedProfileFitter", "classIMP_1_1saxs_1_1WeightedProfileFitter.html", "classIMP_1_1saxs_1_1WeightedProfileFitter" ]
];

==> imp-doc-2.3.1.tar.gz: html/namespaceIMP_1_1saxs.js <==
var namespaceIMP_1_1saxs =
[
    [ "ChiFreeScore", "classIMP_1_1saxs_1_1ChiFreeScore.html", "classIMP_1_1saxs_1_1ChiFreeScore" ],
    [ "ChiScore", "classIMP_1_1saxs_1_1ChiScore.html", "classIMP_1_1saxs_1_1ChiScore" ],
    [ "ChiScoreLog", "classIMP_1_1saxs_1_1ChiScoreLog.html", "classIMP_1_1saxs_1_1ChiScoreLog" ],
    [ "DeltaDistributionFunction", "classIMP_1_1saxs_1_1DeltaDistributionFunction.html", "classIMP_1_1saxs_1_1DeltaDistributionFunction" ],
    [ "DerivativeCalculator", "classIMP_1_1saxs_1_1DerivativeCalculator.html", "classIMP_1_1saxs_1_1DerivativeCalculator" ],
    [ "Distribution", "classIMP_1_1saxs_1_1Distribution.html", "classIMP_1_1saxs_1_1Distribution" ],
    [ "FormFactorTable", "classIMP_1_1saxs_1_1FormFactorTable.html", "classIMP_1_1saxs_1_1FormFactorTable" ],
    [ "Profile", "classIMP_1_1saxs_1_1Profile.html", "classIMP_1_1saxs_1_1Profile" ],
    [ "ProfileFitter", "classIMP_1_1saxs_1_1ProfileFitter.html", "classIMP_1_1saxs_1_1ProfileFitter" ],
    [ "RadialDistributionFunction", "classIMP_1_1saxs_1_1RadialDistributionFunction.html", "classIMP_1_1saxs_1_1RadialDistributionFunction" ],
    [ "RadiusOfGyrationRestraint", "classIMP_1_1saxs_1_1RadiusOfGyrationRestraint.html", "classIMP_1_1saxs_1_1RadiusOfGyrationRestraint" ],
    [ "Restraint", "classIMP_1_1saxs_1_1Restraint.html", "classIMP_1_1saxs_1_1Restraint" ],
    [ "RigidBodiesProfileHandler", "classIMP_1_1saxs_1_1RigidBodiesProfileHandler.html", "classIMP_1_1saxs_1_1RigidBodiesProfileHandler" ],
    [ "SolventAccessibleSurface", "classIMP_1_1saxs_1_1SolventAccessibleSurface.html", "classIMP_1_1saxs_1_1SolventAccessibleSurface" ],
    [ "WeightedProfileFitter", "classIMP_1_1saxs_1_1WeightedProfileFitter.html", "classIMP_1_1saxs_1_1WeightedProfileFitter" ]
];
